Module cli

Module cli 

This module holds the functions that are called from sericom when receiving CLI commands/arguments.

Functions

color_parser
Used as a value_parser for sericoms clap CLI struct to validate and parse args into a SeriColor.
get_settings
Gets the settings for the port with the specified baud.
interactive_session
Spawns all of the tasks responsible for maintaining an interactive terminal session.
list_serial_ports
Prints a list of available serial ports to stdout.
open_connection
Opens a serial port for communication with the specified baud.
valid_baud_rate
Used as a value_parser for sericoms clap CLI struct to validate and parse args into a baud rate.