open_connection

Function open_connection 

pub fn open_connection(baud: u32, port: &str) -> Result<SerialPort>
Opens a serial port for communication with the specified baud.

Returns Ok(SerialPort) or errors if unable to set the baud rate or open the port.