Module errors

Module errors 

This module contains custom errors to provide useful feedback to the user for errors that occur when attempting to parse their config.toml file.

Structs

TomlError
A wrapper around toml::de::Error to print custom error messages with miette.

Enums

ConfigError
A wrapper around error types that may arise from attempting to parse a config file.