create_recursive

Macro create_recursive 

macro_rules! create_recursive {
    ($path:expr) => { ... };
}
Takes a &Path and first checks whether it exists or if it is a directory. If it doesn’t exist or is not a directory, it will create the directory recursively; creating the necessary parent directories.