Module path_utils
sericom_
core
0.7.0
Module path_
utils
Module Items
Macros
Traits
Functions
In crate sericom_
core
sericom_core
Module
path_
utils
Macros

compat_
port_
path
Creates the default filename if none is specified from the
port
name and a timestamp.
create_
recursive
Takes a
&Path
and first checks whether it exists or if it is a directory. If it doesn’t exist or is not a directory, it will create the directory recursively; creating the necessary parent directories.
map_
miette
Used to add a
.map_err()
to function calls that return a
Result<T, E>
to provide better context for the error and print it nicely to stdout.
Traits

Expand
Paths
Trait for expanding paths in a shell-like way.
Functions

is_
script
Validates a script
validate_
dir
Validates a directory