pub struct Line(/* private fields */);Expand description
Line is a wrapper around Vec<Cell> and represents a line within the ScreenBuffer.
Implementations
Sourceimpl Line
impl Line
Sourcepub fn new(width: usize) -> Self
pub fn new(width: usize) -> Self
Create a new line with the length/size of width.
Filled with Cell::default().
Sourcepub fn reset(&mut self)
pub fn reset(&mut self)
Iterates over all the Cells within the line and sets them to Cell::default().
Sourcepub fn reset_to(&mut self, idx: usize)
pub fn reset_to(&mut self, idx: usize)
Iterates over the Cells to index idx within Self
and sets them to Cell::default().
Sourcepub fn reset_from(&mut self, idx: usize)
pub fn reset_from(&mut self, idx: usize)
Iterates over the Cells from index idx within Self
to the end of Self and sets them to Cell::default().
Sourcepub fn clear_selection(&mut self)
pub fn clear_selection(&mut self)
Iterates over the Cells and resets their selected state.