pub struct ScreenBuffer { /* private fields */ }Expand description
The ScreenBuffer holds rendering state for the entire terminal’s window/frame.
It mainly serves to allow for user-interactions that require a history and location
of the data displayed within the terminal i.e. copy/paste, scrolling, & highlighting.
Implementations
Sourceimpl ScreenBuffer
impl ScreenBuffer
Sourcepub fn add_data(&mut self, data: &[u8])
pub fn add_data(&mut self, data: &[u8])
Takes incoming data (bytes (u8) from a serial connection) and
processes them accordingly, handling ascii escape sequences, to
render as characters/strings in the terminal.
Sourcepub fn should_render_now(&self) -> bool
pub fn should_render_now(&self) -> bool
A helper function to check whether the terminal’s screen should be rendered.
Sourcepub fn render(&mut self) -> Result<()>
pub fn render(&mut self) -> Result<()>
Writes the lines/characters received from add_data to the terminal’s screen.
As of now, render does not involve any diff-ing of previous renders.
The nature of communicating to devices over a serial connection is similar that of a terminal; lines get printed to a screen and with each new line, all of the previously rendered characters must be re-rendered one cell higher.
Because of this, the only diff-ing that would make sense would be that of the cells within the screen that are simply blank.