pub struct SerialActor { /* private fields */ }Expand description
Responsible for passing data and messages between the serial connection and tasks. It uses the Actor model to maintain a single source for communicating between the serial connection and tasks within the program.
It broadcasts SerialEvents to worker tasks via a tokio::sync::broadcast
channel, and receives SerialMessages from worker tasks via a tokio::sync::mpsc
channel.
Implementations
Sourceimpl SerialActor
impl SerialActor
Sourcepub fn new(
connection: SerialPort,
command_rx: Receiver<SerialMessage>,
broadcast_channel: Sender<SerialEvent>,
) -> Self
pub fn new( connection: SerialPort, command_rx: Receiver<SerialMessage>, broadcast_channel: Sender<SerialEvent>, ) -> Self
Constructs a SerialActor Takes a serial port connection,
receiver to a command channel, and a sender to a broadcast channel.
Sourcepub async fn run(self)
pub async fn run(self)
This is the heart and soul of the SerialActor.
sericom uses the Actor model to receive data from a serial connection
and forward to other tasks for them to process. It also receives SerialEvents
from tasks and handles them accordingly; writes/sends data to the device
over the serial connection and closes the connection when receiving
SerialMessage::Shutdown, ultimately causing the other tasks to shutdown.
Since data is sent byte-by-byte over a serial connection, run will
batch the data before sending it to other tasks to reduce the number of syscalls.