This module holds the functions that are called from sericom when receiving
CLI commands/arguments.
Functions
- color_
parser - Used as a
value_parserforsericomsclapCLI struct to validate and parse args into aSeriColor. - get_
settings - Gets the settings for the
portwith the specifiedbaud. - interactive_
session - Spawns all of the tasks responsible for maintaining an interactive terminal session.
- list_
serial_ ports - Prints a list of available serial ports to stdout.
- open_
connection - Opens a serial
portfor communication with the specifiedbaud. - valid_
baud_ rate - Used as a
value_parserforsericomsclapCLI struct to validate and parse args into a baud rate.