pub fn open_connection(baud: u32, port: &str) -> Result<SerialPort>Expand description
Opens a serial port for communication with the specified baud.
Returns Ok(SerialPort) or errors if unable to set the baud rate or open the port.
pub fn open_connection(baud: u32, port: &str) -> Result<SerialPort>Opens a serial port for communication with the specified baud.
Returns Ok(SerialPort) or errors if unable to set the baud rate or open the port.