This module contains custom errors to provide useful feedback to the user
for errors that occur when attempting to parse their config.toml file.
Structs
- Toml
Error - A wrapper around
toml::de::Errorto print custom error messages withmiette.
Enums
- Config
Error - A wrapper around error types that may arise from attempting to parse a config file.