As of now, there is only one function, run_debug_output, which is meant
to debug the data being received over the serial connection. In future
updates, this module is intended to be used for running tracing events with
the tracing crate.
Functions
- run_
debug_ output - This function is used for debugging the data that is sent from a device. It will create a file “debug.txt” and print the data received from the device as the actual bytes received along with the corresponding ascii characters.