Module path_utils

Module path_utils 

Macros

compat_port_path
Creates the default filename if none is specified from the port name and a timestamp.
create_recursive
Takes a &Path and first checks whether it exists or if it is a directory. If it doesn’t exist or is not a directory, it will create the directory recursively; creating the necessary parent directories.
map_miette
Used to add a .map_err() to function calls that return a Result<T, E> to provide better context for the error and print it nicely to stdout.

Traits

ExpandPaths
Trait for expanding paths in a shell-like way.

Functions

is_script
Validates a script
validate_dir
Validates a directory