ScreenBuffer

Struct ScreenBuffer 

pub struct ScreenBuffer { /* private fields */ }
The ScreenBuffer holds rendering state for the entire terminal’s window/frame. It mainly serves to allow for user-interactions that require a history and location of the data displayed within the terminal i.e. copy/paste, scrolling, & highlighting.

Implementations

Source

impl ScreenBuffer

pub fn new(width: u16, height: u16, max_scrollback: usize) -> Self

Constructs a new ScreenBuffer to be used at the start of a serial connection session.

pub fn add_data(&mut self, data: &[u8])

Takes incoming data (bytes (u8) from a serial connection) and processes them accordingly, handling ascii escape sequences, to render as characters/strings in the terminal.

pub fn should_render_now(&self) -> bool

A helper function to check whether the terminal’s screen should be rendered.

pub fn scroll_up(&mut self, lines: usize)

Called to scroll the terminal up by lines.

pub fn scroll_down(&mut self, lines: usize)

Called to scroll the terminal down by lines.

pub fn scroll_to_bottom(&mut self)

Scrolls to the bottom of the screen. The bottom of the screen is the same as the most recent lines received from the serial connection

pub fn scroll_to_top(&mut self)

Scrolls to the top of the serial connection’s history.

pub fn start_selection(&mut self, screen_x: u16, screen_y: u16)

Sets the position within the screen for the start of a selection. Where screen_x is the x-position of the start of the selection, and screen_y is the y-position (line) of the start of the selection.

pub fn update_selection(&mut self, screen_x: u16, screen_y: u16)

Update’s a selection to include the position passed to it. Where screen_x is the x-position and screen_y is the y-position (line).

pub fn clear_selection(&mut self)

Clears the selection state.

pub fn copy_to_clipboard(&mut self) -> Result<()>

Copy’s the currently selected text to the user’s clipboard.

pub fn clear_buffer(&mut self)

Clears the entire serial connection’s history and reset’s the screen. Similar to Ctrl + l in a terminal, except this will reset the connection’s message history (on the user’s side).

pub fn render(&mut self) -> Result<()>

Writes the lines/characters received from add_data to the terminal’s screen. As of now, render does not involve any diff-ing of previous renders.

The nature of communicating to devices over a serial connection is similar that of a terminal; lines get printed to a screen and with each new line, all of the previously rendered characters must be re-rendered one cell higher.

Because of this, the only diff-ing that would make sense would be that of the cells within the screen that are simply blank.